@@ -3,7 +3,7 @@
 
 from bits.google.services.base import Base
 from googleapiclient.discovery import build
-from google.cloud.billing_budgets import BudgetServiceClient
+from google.cloud.billing.budgets import BudgetServiceClient
 from google.protobuf import json_format
 
 
@@ -73,4 +73,4 @@ class CloudBillingBudgets(Base):
             'name': name,
             'body': body,
         }
-        return self.budgets.billingAccounts().budgets().get(**params).execute()
+        return self.budgets.billingAccounts().budgets().patch(**params).execute()
