@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """Google Compute API."""
 
 from bits.google.services.base import Base
@@ -21,6 +22,13 @@ class Compute(Base):
         request = instances.list(**params)
         return self.get_list_items(instances, request, 'items')
 
+    def get_networks(self, project):
+        """Return a project's networks."""
+        params = {'project': project}
+        networks = self.compute.networks()
+        request = networks.list(**params)
+        return self.get_list_items(networks, request, 'items')
+
     def get_project(self, project):
         """Return a project."""
         return self.compute.projects().get(project=project).execute()
