@@ -97,6 +97,27 @@ class Drive(Base):
 
     def get_team_drives(self):
         """Return a list of Google Team Drives."""
-        teamDrives = self.drive.teamdrives()
-        request = teamDrives.list(useDomainAdminAccess=True)
-        return self.get_list_items(teamDrives, request, 'teamDrives')
+        drives = self.drive.drives()
+        request = drives.list(useDomainAdminAccess=True)
+        return self.get_list_items(drives, request, 'drives')
+
+    def get_team_drive_files(self, drive_id, fields=None, orderBy=None, q=None):
+        """Return a list of Google Shared/Team Drive files."""
+        fieldnames = [
+            'nextPageToken',
+            'files(id,name,mimeType,ownedByMe,permissions)',
+        ]
+        if not fields:
+            fields = ','.join(sorted(fieldnames))
+        params = {
+            'driveId': drive_id,
+            'fields': fields,
+            'orderBy': orderBy,
+            'q': q,
+            'corpora': 'drive', 
+            'includeItemsFromAllDrives': True,
+            'supportsAllDrives': True,
+        }
+        files = self.drive.files()
+        request = files.list(**params)
+        return self.get_list_items(files, request, 'files')
