@@ -1,10 +1,11 @@
+# -*- coding: utf-8 -*-
 """Google ResourceSearch API."""
 
 from bits.google.services.base import Base
 from googleapiclient.discovery import build
 
 
-class ResourceSearch(object):
+class ResourceSearch(Base):
     """ResourceSearch class."""
 
     def __init__(self, credentials):
